var searchData=
[
  ['hasher_0',['Hasher',['../classopencc_1_1_u_t_f8_string_slice_base_1_1_hasher.html',1,'opencc::UTF8StringSliceBase']]],
  ['history_20版本歷史_1',['Change History 版本歷史',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md31',1,'']]]
];
